# QIR Formatter

QIR Formatter is a Python library for formatting results from the
[QIR Labeled Output Schema](https://github.com/qir-alliance/qir-spec/blob/a67da3a3bd902ba7cd94a98722ca5f8c89f5a81a/specification/under_development/output_schemas/Labeled.md).

## Development

```sh
uv sync
```

## Testing

```sh
uv run pytest
```
